==> uui-breadcrumbs-0.0.11.tgz: package/lib/uui-breadcrumb-item.element.js <==
import { css, LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';

var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
class UUIBreadcrumbItemElement extends LitElement {
  constructor() {
    super(...arguments);
    this.href = "#";
    this.lastItem = false;
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "listitem");
  }
  render() {
    return html`${this.lastItem ? html`<span id="last-item"><slot></slot></span>` : html`<a id="link" href=${this.href}><slot></slot></a>`}<span
        part="separator"></span>`;
  }
}
UUIBreadcrumbItemElement.styles = [
  css`
      :host {
        font-size: var(--uui-size-small, 12px);
        color: currentColor;
      }

      a,
      a:visited {
        color: currentColor;
      }

      :host(:last-of-type) [part='separator'],
      :host([last-item]) [part='separator'] {
        display: none;
      }

      [part='separator']::after {
        content: '/';
        speak: never;
        position: relative;
        top: 1px;
        margin: -3px 1px 0;
        color: var(--uui-interface-border, #c4c4c4);
      }

      #link,
      #last-item {
        padding: 0 4px;
        max-width: 150px;
        white-space: nowrap;
        overflow: hidden;
        text-overflow: ellipsis;
      }

      #link {
        cursor: pointer;
      }
    `
];
__decorateClass([
  property()
], UUIBreadcrumbItemElement.prototype, "href", 2);
__decorateClass([
  property({ type: Boolean, attribute: "last-item" })
], UUIBreadcrumbItemElement.prototype, "lastItem", 2);

export { UUIBreadcrumbItemElement };

==> uui-breadcrumbs-0.0.12.tgz: package/lib/uui-breadcrumb-item.element.js <==
import { css, LitElement, html } from 'lit';
import { property } from 'lit/decorators.js';

var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};
class UUIBreadcrumbItemElement extends LitElement {
  constructor() {
    super(...arguments);
    this.href = "#";
    this.lastItem = false;
  }
  connectedCallback() {
    super.connectedCallback();
    this.setAttribute("role", "listitem");
  }
  render() {
    return html`${this.lastItem ? html`<span id="last-item"><slot></slot></span>` : html`<a id="link" href=${this.href}><slot></slot></a>`}<span
        part="separator"></span>`;
  }
}
UUIBreadcrumbItemElement.styles = [
  css`
      :host {
        font-size: var(--uui-size-4,12px);
        color: currentColor;
      }

      a,
      a:visited {
        color: currentColor;
      }

      :host(:last-of-type) [part='separator'],
      :host([last-item]) [part='separator'] {
        display: none;
      }

      [part='separator']::after {
        content: '/';
        speak: never;
        position: relative;
        top: 1px;
        margin: -3px 1px 0;
        color: var(--uui-interface-border, #c4c4c4);
      }

      #link,
      #last-item {
        padding: 0 4px;
        max-width: 150px;
        white-space: nowrap;
        overflow: hidden;
        text-overflow: ellipsis;
      }

      #link {
        cursor: pointer;
      }
    `
];
__decorateClass([
  property()
], UUIBreadcrumbItemElement.prototype, "href", 2);
__decorateClass([
  property({ type: Boolean, attribute: "last-item" })
], UUIBreadcrumbItemElement.prototype, "lastItem", 2);

export { UUIBreadcrumbItemElement };
